import SkribblClient from "../logic/SkribblClient.js";
import SkribblPlayerList from "./SkribblPlayerList.js";
import SkribblSettings from "./SkribblSettings.js";

/**
 * Custom element `<skribbl-lobby>` for the lobby of a game.
 */
export default class SkribblLobby extends HTMLElement {
	/**
	 * @param {SkribblClient} client
	 */
	constructor(client){
		super();
		this.attachShadow({mode:"open"});
		this.shadowRoot.innerHTML = `
			<style>
				:host {
					display: flex;
				}
				#left {
					width: 60%;
				}
				skribbl-player-list {
					width: 40%;
				}
				skribbl-url {
					margin-top: 5px;
				}
			</style>
			<div id="left"></div>
		`;
		let settings = new SkribblSettings(client);
		let playerList = new SkribblPlayerList(client);
		let url = new SkribblURL(client.url);
		let left = this.shadowRoot.querySelector("#left");
		left.append(settings,url);
		this.shadowRoot.append(playerList);
	}
}
/**
 * Custom element `<skribbl-url>` for the URL displayed in the lobby of the game.
 */
export class SkribblURL extends HTMLElement {
	/**
	 * @param {string} url
	 */
	constructor(url){
		super();
		this.attachShadow({mode:"open"});
		this.shadowRoot.innerHTML = `
			<style>
				:host {
					display: flex;
					align-items: center;
					background: #ffffff;
					border-radius: 10px;
					padding: 10px;
				}
				:host > div {
					flex-grow: 1;
					flex-shrink: 1;
				}
				button {
					margin: -5px -5px -5px 0;
					padding: 4px 15px;
					font-size: 16px;
					background: orange;
					color: white;
					border: none;
					border-radius: 4px;
					cursor: pointer;
				}
			</style>
			<div>
				<b>Invite link:</b> <span id="link"></span>
			</div>
			<button>Copy</button>
		`;
		this._url = url;
		this._urlSpan = this.shadowRoot.getElementById("link");
		this._urlSpan.textContent = url;
		this._button = this.shadowRoot.querySelector("button");
		this._button.addEventListener("click",e=>{
			navigator.clipboard.writeText(url);
		});
	}
}
customElements.define("skribbl-lobby",SkribblLobby);
customElements.define("skribbl-url",SkribblURL);